# Django GREP

The complete core library for the CTC website (formerly wagtail-ctc), including:
- **Components**: Block framework for Wagtail.
- **Pipelines**: Enhanced model workflows and utilities.
- **Utils**: Shared core utilities.

## Installation

```bash
pip install django-grep
```
